"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("reflect-metadata");
require("jasmine");
var utils_1 = require("../../utils");
var src_1 = require("../../../src");
describe('UNIT TEST event.recorder', function () {
    describe('createBuffer()', function () {
        it('should do nothing if serverNode empty', function () {
            var root = {
                serverSelector: 'body',
                serverNode: {}
            };
            var actual = src_1.createBuffer(root);
            expect(actual).toBe(root.serverNode);
        });
        it('should clone the node and insert before', function () {
            var root = {
                serverSelector: 'div',
                serverNode: utils_1.getMockElement()
            };
            var clientNode = { style: { display: 'block' } };
            root.serverNode.cloneNode = function () {
                return clientNode;
            };
            var actual = src_1.createBuffer(root);
            expect(actual).toBe(clientNode);
        });
    });
    describe('getSelection()', function () {
        it('should return default if no value', function () {
            var node = {};
            var expected = {
                start: 0,
                end: 0,
                direction: 'forward'
            };
            var actual = src_1.getSelection(node);
            expect(actual).toEqual(expected);
        });
        it('should return selection for older browsers', function () {
            var node = { value: 'foo' };
            var expected = {
                start: 3,
                end: 3,
                direction: 'forward'
            };
            var actual = src_1.getSelection(node);
            expect(actual).toEqual(expected);
        });
        it('should return selection for modern browsers', function () {
            var node = {
                value: 'foo',
                selectionStart: 1,
                selectionEnd: 2,
                selectionDirection: 'reverse'
            };
            var expected = {
                start: 1,
                end: 2,
                direction: 'reverse'
            };
            var actual = src_1.getSelection(node);
            expect(actual).toEqual(expected);
        });
    });
    describe('createListenHandler()', function () {
        it('should do nothing if not listening', function () {
            var prebootData = {
                listening: false
            };
            var eventSelector = {
                selector: '',
                events: [],
                preventDefault: true
            };
            var appData = {
                root: {
                    serverSelector: '',
                    serverNode: {}
                },
                events: []
            };
            var event = {
                preventDefault: function () { }
            };
            var node = {};
            spyOn(event, 'preventDefault');
            var handler = src_1.createListenHandler(prebootData, eventSelector, appData, node);
            handler(event);
            expect(event.preventDefault).not.toHaveBeenCalled();
        });
    });
});
//# sourceMappingURL=event.recorder.spec.js.map