"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("reflect-metadata");
require("jasmine");
var src_1 = require("../../../src");
describe('UNIT TEST inline.preboot.code', function () {
    describe('stringifyWithFunctions()', function () {
        it('should do the same thing as stringify if no functions', function () {
            var obj = { foo: 'choo', woo: 'loo', zoo: 5 };
            var expected = JSON.stringify(obj);
            var actual = src_1.stringifyWithFunctions(obj);
            expect(actual).toEqual(expected);
        });
        it('should stringify an object with functions', function () {
            var obj = {
                blah: 'foo',
                zoo: function (blah) {
                    return blah + 1;
                }
            };
            var expected = '{"blah":"foo","zoo":function (';
            var actual = src_1.stringifyWithFunctions(obj);
            expect(actual.substring(0, 30)).toEqual(expected);
        });
    });
    describe('assign()', function () {
        it('should merge two objects', function () {
            var obj1 = { val1: 'foo', val2: 'choo' };
            var obj2 = { val2: 'moo', val3: 'zoo' };
            var expected = { val1: 'foo', val2: 'moo', val3: 'zoo' };
            var actual = src_1.assign(obj1, obj2);
            expect(actual).toEqual(expected);
        });
    });
    describe('validateOptions()', function () {
        it('should throw error if nothing passed in', function () {
            expect(function () { return src_1.validateOptions({}); }).toThrowError(/appRoot is missing/);
        });
    });
    describe('getEventRecorderCode()', function () {
        it('should generate valid JavaScript by default', function () {
            var code = src_1.getEventRecorderCode();
            expect(code).toBeTruthy();
        });
    });
    describe('getInlinePrebootCode()', function () {
        it('should generate valid JavaScript minified', function () {
            var code = src_1.getInlinePrebootCode({ appRoot: 'foo' });
            expect(code).toBeTruthy();
        });
        it('should generate valid JavaScript not minified', function () {
            var code = src_1.getInlinePrebootCode({ appRoot: 'foo', minify: false });
            expect(code).toBeTruthy();
        });
    });
});
//# sourceMappingURL=inline.preboot.code.spec.js.map